<?php
/**
*
* search_ignore_words [Deutsch — Sie]
*
* @package language
* @version $Id: search_ignore_words.php 617 2013-09-29 10:21:18Z pyramide $
* @copyright (c) 2005 phpBB Group; 2006 phpBB.de
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
* Deutsche Übersetzung durch die Übersetzer-Gruppe von phpBB.de:
* siehe docs/AUTHORS und https://www.phpbb.de/go/ubersetzerteam
*
*/

if (!defined('IN_PHPBB'))
{
	exit;
}

$words = array(
	'aber',
	'abgesehen',
	'ach',
	'alle',
	'allein',
	'aller',
	'alles',
	'als',
	'also',
	'andere',
	'anderen',
	'anderenfalls',
	'anderer',
	'anderes',
	'anstatt',
	'auch',
	'auf',
	'aus',
	'außen',
	'aussen',
	'außer',
	'ausser',
	'außerdem',
	'ausserdem',
	'außerhalb',
	'ausserhalb',
	'ändern',
	'behalten',
	'bei',
	'beide',
	'beiden',
	'beider',
	'beides',
	'beim',
	'beinahe',
	'besser',
	'bevor',
	'bin',
	'bis',
	'bist',
	'bitte',
	'bzw',
	'cool',
	'dabei',
	'daher',
	'damit',
	'danach',
	'dank',
	'danke',
	'dann',
	'darüber',
	'darüberhinaus',
	'darueber',
	'darueberhinaus',
	'darum',
	'das',
	'daß',
	'dass',
	'dazu',
	'dein',
	'deine',
	'deiner',
	'deines',
	'deins',
	'den',
	'denk',
	'denke',
	'denken',
	'dem',
	'den',
	'denn',
	'der',
	'des',
	'deshalb',
	'dich',
	'die',
	'diese',
	'diesem',
	'diesen',
	'dieser',
	'dieses',
	'dir',
	'doch',
	'dort',
	'duerfte',
	'duerften',
	'duerftest',
	'duerftet',
	'durch',
	'durfte',
	'dürfte',
	'durften',
	'dürften',
	'durftest',
	'dürftest',
	'durftet',
	'dürftet',
	'echt',
	'eigen',
	'eigener',
	'eigenes',
	'eigentlich',
	'ein',
	'eine',
	'einem',
	'einen',
	'einer',
	'eines',
	'einfach',
	'einige',
	'einiger',
	'einiges',
	'entgegen',
	'entweder',
	'erscheinen',
	'erst',
	'es',
	'etwas',
	'euch',
	'fast',
	'fertig',
	'finde',
	'finden',
	'fort',
	'fuer',
	'für',
	'ganz',
	'gar',
	'gegen',
	'gegenüber',
	'gegenueber',
	'gehalten',
	'geht',
	'geil',
	'gemacht',
	'gemaess',
	'gemäß',
	'genau',
	'genug',
	'gerade',
	'gern',
	'gerne',
	'getan',
	'getrennt',
	'gewesen',
	'gibt',
	'grins',
	'gruss',
	'gruß',
	'gruendlich',
	'gründlich',
	'grüße',
	'gut',
	'gute',
	'guten',
	'gutes',
	'hab',
	'habe',
	'haben',
	'habt',
	'haeufig',
	'häufig',
	'hallo',
	'halt',
	'hast',
	'hat',
	'hatte',
	'hatten',
	'hattest',
	'hattet',
	'heute',
	'hier',
	'hindurch',
	'hintendran',
	'hinter',
	'hinunter',
	'hrhr',
	'ich',
	'ihm',
	'ihnen',
	'ihr',
	'ihre',
	'ihrem',
	'ihren',
	'ihrer',
	'ihres',
	'ihrige',
	'ihrigen',
	'ihriges',
	'immer',
	'indem',
	'innerhalb',
	'innerlich',
	'ins',
	'irgendetwas',
	'irgendwas',
	'irgendwelche',
	'irgendwenn',
	'irgendwie',
	'irgendwo',
	'irgendwohin',
	'iss',
	'issn',
	'ist',
	'ja',
	'jede',
	'jedem',
	'jeden',
	'jeder',
	'jedes',
	'jedoch',
	'jemals',
	'jemand',
	'jemandem',
	'jemanden',
	'jemandes',
	'jene',
	'jetzt',
	'jung',
	'junge',
	'jungem',
	'jungen',
	'junger',
	'junges',
	'leider',
	'link',
	'lol',
	'kann',
	'kannst',
	'kaum',
	'kein',
	'keine',
	'koennen',
	'koennt',
	'koennte',
	'koennten',
	'koenntest',
	'koenntet',
	'komme',
	'kommen',
	'kommt',
	'können',
	'könnt',
	'konnte',
	'könnte',
	'konnten',
	'könnten',
	'konntest',
	'könntest',
	'konntet',
	'könntet',
	'liebe',
	'lieber',
	'liebes',
	'machen',
	'macht',
	'machte',
	'mal',
	'man',
	'mehr',
	'mehrere',
	'mein',
	'meine',
	'meinem',
	'meinen',
	'meiner',
	'meines',
	'meins',
	'meistens',
	'mfg',
	'mich',
	'mir',
	'mit',
	'moin',
	'mrgreen',
	'muessen',
	'muesst',
	'muß',
	'muss',
	'müssen',
	'mußt',
	'musst',
	'müßt',
	'nach',
	'nachdem',
	'naja',
	'nächste',
	'naechste',
	'natürlich',
	'nebenan',
	'nein',
	'nem',
	'nen',
	'net',
	'neu',
	'neue',
	'neuen',
	'neuem',
	'neues',
	'neuer',
	'nicht',
	'nichts',
	'nie',
	'niemand',
	'niemandem',
	'niemanden',
	'niemandes',
	'nirgendwo',
	'nix',
	'nnen',
	'nnte',
	'noch',
	'nochmal',
	'nun',
	'nur',
	'oben',
	'obwohl',
	'oder',
	'oft',
	'ohne',
	'paar',
	'pro',
	'quot',
	'roll',
	'sage',
	'sagen',
	'sagte',
	'sagten',
	'sagtest',
	'sagtet',
	'scheinen',
	'schon',
	'schön',
	'schöne',
	'schöner',
	'schönes',
	'schrieb',
	'sehe',
	'sehen',
	'sehr',
	'sei',
	'seid',
	'seien',
	'seiest',
	'seiet',
	'sein',
	'seine',
	'seinem',
	'seinen',
	'seiner',
	'seines',
	'seit',
	'selbst',
	'sich',
	'sie',
	'sieht',
	'sind',
	'smile',
	'sogar',
	'solche',
	'solchem',
	'solchen',
	'solcher',
	'solches',
	'soll',
	'sollte',
	'sollten',
	'solltest',
	'solltet',
	'sondern',
	'sonst',
	'statt',
	'stets',
	'tatsächlich',
	'tatsaechlich',
	'thema',
	'tief',
	'tpl',
	'tun',
	'tut',
	'über',
	'überll',
	'ueber',
	'ueberall',
	'und',
	'uns',
	'unser',
	'unsere',
	'unserem',
	'unseren',
	'unserer',
	'unseres',
	'unten',
	'unter',
	'unterhalb',
	'user',
	'usw',
	'viel',
	'viele',
	'vielleicht',
	'vom',
	'von',
	'vor',
	'vorbei',
	'vorher',
	'vorüber',
	'vorueber',
	'waehrend',
	'während',
	'wär',
	'wäre',
	'wann',
	'war',
	'waren',
	'warst',
	'wart',
	'warum',
	'was',
	'wär',
	'wäre',
	'weder',
	'wegen',
	'weil',
	'weiss',
	'weiß',
	'weit',
	'weiter',
	'weitere',
	'weiterem',
	'weiteren',
	'weiterer',
	'weiteres',
	'welche',
	'welchem',
	'welchen',
	'welcher',
	'welches',
	'wem',
	'wen',
	'wenige',
	'wenn',
	'wer',
	'werde',
	'werden',
	'werdet',
	'wessen',
	'wie',
	'wieder',
	'will',
	'wink',
	'winke',
	'wir',
	'wird',
	'wirklich',
	'wirst',
	'wohin',
	'wohl',
	'wuerde',
	'wuerden',
	'wuerdest',
	'wuerdet',
	'wurde',
	'würde',
	'wurden',
	'würden',
	'wurdest',
	'würdest',
	'wurdet',
	'würdet',
	'www',
	'ziemlich',
	'zum',
	'zur',
	'zusammen',
	'zwar',
	'zwischen',
);

?>