<?php
/**
*
* search_synonyms [Deutsch — Sie]
*
* @package language
* @version $Id: search_synonyms.php 617 2013-09-29 10:21:18Z pyramide $
* @copyright (c) 2005 phpBB Group; 2006 phpBB.de
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
* Deutsche Übersetzung durch die Übersetzer-Gruppe von phpBB.de:
* siehe docs/AUTHORS und https://www.phpbb.de/go/ubersetzerteam
*
*/

if (!defined('IN_PHPBB'))
{
	exit;
}

$synonyms = array(
	'Abfluß'			=> 'Abfluss',
	'Abschluß'			=> 'Abschluss',
	'Adreßbuch'			=> 'Adressbuch',
	'Anlaß'				=> 'Anlass',
	'anläßlich'			=> 'anlässlich',
	'Anschluß'			=> 'Anschluss',
	'aufschlußreich'	=> 'aufschlussreich',
	'aufwendig'			=> 'aufwändig',
	'Ausschluß'			=> 'Ausschluss',

	'Beschluß'		=> 'Beschluss',
	'Bestelliste'	=> 'Bestellliste',
	'Bettuch'		=> 'Betttuch',
	'bewußt'		=> 'bewusst',
	'Bibliographie'	=> 'Bibliografie',
	'Biographie'	=> 'Biografie',
	'bißchen'		=> 'bisschen',
	'blaß'			=> 'blass',
	'Börsentip'		=> 'Börsentipp',
	'Brennessel'	=> 'Brennnessel',
	'Bukett'		=> 'Bouquet',
	'Butike'		=> 'Boutique',

	'chic'		=> 'schick',
	'Club'		=> 'Klub',
	'Coffein'	=> 'Koffein',
	'Coupon'	=> 'Kupon',

	'Demographie'	=> 'Demografie',
	'deplaziert'	=> 'deplatziert',
	'Differential'	=> 'Differenzial',
	'Discothek'		=> 'Diskothek',
	'Doppelpaß'		=> 'Doppelpass',

	'Einfluß'		=> 'Einfluss',
	'Eisschnellauf'	=> 'Eisschnelllauf',
	'Entschluß'		=> 'Entschluss',
	'erfaßbar'		=> 'erfassbar',
	'erstplaziert'	=> 'erstplatziert',
	'existentiell'	=> 'existenziell',

	'Fitneßstudio'		=> 'Fitnessstudio',
	'Freßsucht'			=> 'Fresssucht',
	'Fußballänderspiel'	=> 'Fußballländerspiel',

	'Geschoß'	=> 'Geschoss',
	'Gewißheit'	=> 'Gewissheit',
	'Graphit'	=> 'Grafit',

	'häßlich'	=> 'hässlich',

	'Imbiß'			=> 'Imbiss',
	'Imbißstand'	=> 'Imbissstand',
	'Interresse'	=> 'Interesse',

	'Jacht'		=> 'Yacht',
	'Jogurt'	=> 'Joghurt',

	'Känguruh'		=> 'Känguru',
	'Karamel'		=> 'Karamell',
	'Kennummer'		=> 'Kennnummer',
	'Ketschup'		=> 'Ketchup',
	'Kompaß'		=> 'Kompass',
	'Kompromiß'		=> 'Kompromiss',
	'Kongreßsaal'	=> 'Kongresssaal',
	'Kongreßstadt'	=> 'Kongressstadt',
	'Kontrollampe'	=> 'Kontrolllampe',
	'Kontrolliste'	=> 'Kontrollliste',
	'Kreme'			=> 'Creme',
	'Kuß'			=> 'Kuss',

	'läßt'	=> 'lässt',

	'Megaphon'			=> 'Megafon',
	'Meßstab'			=> 'Messstab',
	'Metallegierung'	=> 'Metalllegierung',
	'Mikrophon'			=> 'Mikrofon',
	'Mißbrauch'			=> 'Missbrauch',
	'muß'				=> 'muss',

	'naß'			=> 'nass',
	'Nugat'			=> 'Nougat',
	'Nullösung'		=> 'Nulllösung',
	'numerieren'	=> 'nummerieren',
	'Nuß'			=> 'Nuss',

	'Orthographie'	=> 'Orthografie',

	'Panther'		=> 'Panter',
	'Paragraph'		=> 'Paragraf',
	'Paß'			=> 'Pass',
	'Paßstraße'		=> 'Passstraße',
	'Phantasie'		=> 'Fantasie',
	'Photo'			=> 'Foto',
	'Photos'		=> 'Fotos',
	'Photosynthese'	=> 'Fotosynthese',
	'Plazierung'	=> 'Platzierung',
	'Portemonnaie'	=> 'Portmonee',
	'Potential'		=> 'Potenzial',
	'programmäßig'	=> 'programmmäßig',
	'Prozeß'		=> 'Prozess',

	'Quentchen'	=> 'Quäntchen',

	'rauh'		=> 'rau',
	'Riß'		=> 'Riss',
	'Rolladen'	=> 'Rollladen',
	'Rußland'	=> 'Russland',

	'Saxophon'			=> 'Saxofon',
	'Schi'				=> 'Ski',
	'Schiffahrt'		=> 'Schifffahrt',
	'Schloß'			=> 'Schloss',
	'Schluß'			=> 'Schluss',
	'Schnellauf'		=> 'Schnelllauf',
	'schnellebig'		=> 'schnelllebig',
	'selbständig'		=> 'selbstständig',
	'Spagetti'			=> 'Spaghetti',
	'Sperriegel'		=> 'Sperrriegel',
	'Stengel'			=> 'Stängel',
	'Stewardeß'			=> 'Stewardess',
	'stillegen'			=> 'stilllegen',
	'Stillegung'		=> 'Stilllegung',
	'Stoffetzen'		=> 'Stofffetzen',
	'Stop'				=> 'Stopp',
	'Streßsituation'	=> 'Stresssituation',
	'substantiell'		=> 'substanziell',

	'Telephon'	=> 'Telefon',
	'Thunfisch'	=> 'Tunfisch',
	'Tip'		=> 'Tipp',
	'Tolpatsch'	=> 'Tollpatsch',

	'Überfluß'	=> 'Überfluss',

	'Win'	=> 'Windows',

	'zeitaufwendig'	=> 'zeitaufwändig',);
?>